/*******************************************************************************
* File Name: ZC.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ZC.h"

static ZC_BACKUP_STRUCT  ZC_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: ZC_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet ZC_SUT.c usage_ZC_Sleep_Wakeup
*******************************************************************************/
void ZC_Sleep(void)
{
    #if defined(ZC__PC)
        ZC_backup.pcState = ZC_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            ZC_backup.usbState = ZC_CR1_REG;
            ZC_USB_POWER_REG |= ZC_USBIO_ENTER_SLEEP;
            ZC_CR1_REG &= ZC_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(ZC__SIO)
        ZC_backup.sioState = ZC_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        ZC_SIO_REG &= (uint32)(~ZC_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: ZC_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to ZC_Sleep() for an example usage.
*******************************************************************************/
void ZC_Wakeup(void)
{
    #if defined(ZC__PC)
        ZC_PC = ZC_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            ZC_USB_POWER_REG &= ZC_USBIO_EXIT_SLEEP_PH1;
            ZC_CR1_REG = ZC_backup.usbState;
            ZC_USB_POWER_REG &= ZC_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(ZC__SIO)
        ZC_SIO_REG = ZC_backup.sioState;
    #endif
}


/* [] END OF FILE */
